@@ -1,7 +1,3 @@
-try:
-    from urllib.request import urlopen
-except ImportError:
-    from urllib2 import urlopen
 import yaml
 try:
     import urlparse
@@ -22,6 +18,8 @@ from .rosdistrohelper import get_targets, get_release_file, PreRep137Warning
 
 from .rep3 import download_targets_data  # deprecated, will output warning
 
+from .url_utils import urlopen_gzip
+
 import warnings
 
 create_default_installer_context = None
@@ -201,7 +199,7 @@ def download_gbpdistro_as_rosdep_data(gbpdistro_url, targets_url=None):
     # will output a warning
     targets_data = download_targets_data(targets_url=targets_url)
     try:
-        f = urlopen(gbpdistro_url, timeout=DOWNLOAD_TIMEOUT)
+        f = urlopen_gzip(gbpdistro_url, timeout=DOWNLOAD_TIMEOUT)
         text = f.read()
         f.close()
         gbpdistro_data = yaml.safe_load(text)
