@@ -1,8 +1,10 @@
 from rosdep2.catkin_support import get_installer, get_catkin_view, ValidationFailed, resolve_for_os
 
 from rosdep2.platforms.debian import APT_INSTALLER
+import pytest
 
 
+@pytest.mark.online
 def test_workflow():
     try:
         installer = get_installer(APT_INSTALLER)
